import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/* Router Modules */
// import componentsRouter from './modules/components'
// import chartsRouter from './modules/charts'
// import tableRouter from './modules/table'
// import nestedRouter from './modules/nested'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    noCache: true                if set true, the page will no be cached(default is false)
    affix: true                  if set true, the tag will affix in the tags-view
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path(.*)',
        component: () => import('@/views/redirect/index')
      }
    ]
  },
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/Register',
    name: 'Register',
    component: () => import('@/views/login/Register'),
    hidden: true
  },
  // {
  //   path: '/profile',
  //   component: () => import('@/views/login/profile'),
  //   hidden: true
  // },
  {
    path: '/auth-redirect',
    component: () => import('@/views/login/auth-redirect'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/error-page/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/error-page/401'),
    hidden: true
  },
  {
    path: '/',
    component: Layout,
    redirect: '/home',
    children: [
      {
        path: 'home',
        component: () => import('@/views/home/index'),
        name: 'Home',
        meta: { title: '首页', icon: 'el-icon-s-home', affix: true }
      }
    ]
  },
  {
    path: '/user',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: 'profile',
        component: () => import('@/views/user/profile/index'),
        name: 'Profile',
        meta: { title: '个人中心', icon: 'user' }
      }
    ]
  }
]

//  {
//   path: '/budget123',
//   component: Layout,
//   redirect: '/budget/fee/type',
//   name: 'suply-chain',
//   meta: {
//     title: '预算报价',
//     icon: 'el-icon-edit'
//   },
//   children: [

//     {
//       path: '4041',
//       component: () => import('@/views/budget/404'),
//       name: 'Page404',
//       meta: { title: '报价管理', noCache: true }
//     }
//   ]
// },
// {
//   path: '/produce',
//   component: Layout,
//   redirect: 'noRedirect',
//   name: 'suply-chain',
//   meta: {
//     title: '生产管理',
//     icon: 'el-icon-files'
//   },
//   children: [
//     {
//       path: '401',
//       component: () => import('@/views/error-page/401'),
//       name: 'Page401',
//       meta: { title: 'page401', noCache: true }
//     },
//     {
//       path: '404',
//       component: () => import('@/views/error-page/404'),
//       name: 'Page404',
//       meta: { title: 'page404', noCache: true }
//     }
//   ]
// },
// {
//   path: '/goods',
//   component: Layout,
//   redirect: 'noRedirect',
//   name: 'suply-chain',
//   meta: {
//     title: '物资管理',
//     icon: 'el-icon-s-ticket'
//   },
//   children: [
//     {
//       path: '401',
//       component: () => import('@/views/error-page/401'),
//       name: 'Page401',
//       meta: { title: 'page401', noCache: true }
//     },
//     {
//       path: '404',
//       component: () => import('@/views/error-page/404'),
//       name: 'Page404',
//       meta: { title: 'page404', noCache: true }
//     }
//   ]
// },

// {
//   path: '/client',
//   component: Layout,
//   redirect: 'noRedirect',
//   name: 'suply-chain',
//   meta: {
//     title: '客户管理',
//     icon: 'peoples'
//   },
//   children: [
//     {
//       path: '401',
//       component: () => import('@/views/error-page/401'),
//       name: 'Page401',
//       meta: { title: '甲方管理', noCache: true },
//       children: [
//         {
//           path: '401',
//           component: () => import('@/views/error-page/401'),
//           name: 'Page401',
//           meta: { title: 'page401', noCache: true }

//         },
//         {
//           path: '404',
//           component: () => import('@/views/error-page/404'),
//           name: 'Page404',
//           meta: { title: 'page404', noCache: true }
//         }
//       ]
//     },
//     {
//       path: '404',
//       component: () => import('@/views/error-page/404'),
//       name: 'Page404',
//       meta: { title: '乙方管理', noCache: true },
//       children: [
//         {
//           path: '401',
//           component: () => import('@/views/error-page/401'),
//           name: 'Page401',
//           meta: { title: 'page401', noCache: true }

//         },
//         {
//           path: '404',
//           component: () => import('@/views/error-page/404'),
//           name: 'Page404',
//           meta: { title: 'page404', noCache: true }
//         }
//       ]
//     }
//   ]
// },
/**
 * asyncRoutes
 * the routes that need to be dynamically loaded based on user roles
 */
export const asyncRoutes = [
  // {
  //   path: '/profile',
  //   component: Layout,
  //   hidden: true,
  //   children: [
  //     {
  //       path: '/',
  //       component: r => require.ensure([], () => r(require('@/views/Index')), 'index')
  //     },
  //     {
  //       path: '/newsuser/personal/:id',
  //       component: r => require.ensure([], () => r(require('@/views/person/Personal')), 'personal'),
  //       meta: {
  //         requireLogin: true
  //       },
  //       children: [
  //         {
  //           path: '/personal/info/:id',
  //           // path: '/newsuser/personal/info/:id',
  //           name: 'info',
  //           component: r => require.ensure([], () => r(require('@/views/person/Info')), 'info')
  //         },
  //         {
  //           path: '/newsuser/personal/myarticle/:id',
  //           name: 'myarticle',
  //           component: r => require.ensure([], () => r(require('@/views/person/MyArticle')), 'myarticle')
  //         },
  //         {
  //           path: '/newsuser/personal/mycollect/:id',
  //           name: 'mycollect',
  //           component: r => require.ensure([], () => r(require('@/views/person/MyCollect')), 'mycollect')
  //         },
  //         {
  //           path: '/newsuser/personal/myfan/:id',
  //           name: 'myfan',
  //           component: r => require.ensure([], () => r(require('@/views/person/MyFanAndFollow')), 'myfan')
  //         },
  //         {
  //           path: '/newsuser/personal/myfollow/:id',
  //           name: 'myfollow',
  //           component: r => require.ensure([], () => r(require('@/views/person/MyFanAndFollow')), 'myfollow')
  //         }
  //       ]
  //     }
  //   ]
  // },
  {
    path: '/cranes',
    component: Layout,
    redirect: 'noRedirect',
    name: 'suply-chain',
    meta: {
      title: '天车管理',
      icon: 'el-icon-s-grid',
      roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'] // you can set roles in root nav
    },
    children: [

      {
        path: 'info',
        component: () => import('@/views/crane/index'),
        name: 'info',
        meta: {
          title: '天车信息',
          roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'], // you can set roles in root nav
          noCache: true
        }
      },
      {
        path: 'devices',
        component: () => import('@/views/crane/device'),
        name: 'test',
        meta: {
          title: '设备信息',
          roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'], // you can set roles in root nav
          noCache: true
        }
      }

    ]
  },
  {
    path: '/detection',
    component: Layout,
    meta: {
      title: '智能检测',
      icon: 'el-icon-finished'
      // roles: ['ROLE_ULTIMATE','ROLE_ADMIN'] // you can set roles in root nav
    },
    children: [
      {
        path: 'online',
        component: () => import('@/views/detection/online'),
        name: 'online',
        meta: {
          title: '实时数据',
          roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'], // you can set roles in root nav
          noCache: true
        }
      },
      {
        path: 'history',
        component: () => import('@/views/detection/history'),
        name: 'history',
        meta: {
          title: '历史数据',
          roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'], // you can set roles in root nav
          noCache: true
        }
      },
      {
        path: 'home',
        component: () => import('@/views/detection/online'),
        name: 'Home',
        meta: { title: '设备总览', affix: true }
      },

      {
        path: 'setting',
        component: () => import('@/views/detection/setting'),
        name: 'test',
        meta: {
          title: '设置',
          roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'], // you can set roles in root nav
          noCache: true
        },
        children: [

          {
            path: 'source',
            component: () => import('@/views/detection/setting/source'),
            name: 'dataSource',
            meta: {
              title: '数据源',
              roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'], // you can set roles in root nav
              noCache: true
            }
          },
          {
            path: 'type',
            component: () => import('@/views/detection/setting/type'),
            name: 'dataType',
            meta: {
              title: '数据类型',
              roles: ['ROLE_ULTIMATE'] // you can set roles in root nav

              // if do not set roles, means: this page does not require permission
            }

          }

        ]
      }
    ]
  },

  {
    path: '/repair',
    component: Layout,
    redirect: 'noRedirect',
    name: 'suply-chain',
    meta: {
      title: '维修管理',
      icon: 'el-icon-s-finance',
      roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'] // you can set roles in root nav
    },
    children: [
      {
        path: 'record',
        component: () => import('@/views/repair/index'),
        name: 'add',
        meta: {
          title: '维修记录',
          roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'], // you can set roles in root nav
          noCache: true
        }
      },
      {
        path: 'standard',
        component: () => import('@/views/repair/standard'),
        name: 'test',
        meta: {
          title: '维修标准',
          roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'], // you can set roles in root nav
          noCache: true
        }
      },
      {
        path: 'fault',
        component: () => import('@/views/repair/fault'),
        name: 'dataType',
        meta: {
          title: '故障记录',
          roles: ['ROLE_ULTIMATE'] // you can set roles in root nav

          // if do not set roles, means: this page does not require permission
        }

      }

    ]
  },
  // {
  //   path: '/devices',
  //   component: Layout,
  //   redirect: 'noRedirect',
  //   name: 'suply-chain',
  //   meta: {
  //     title: '设备管理',
  //     icon: 'el-icon-s-cooperation',
  //     roles: ['ROLE_ULTIMATE','ROLE_ADMIN'] // you can set roles in root nav
  //   },
  //   children: [
  //     {
  //       path: 'add',
  //       component: () => import('@/views/crane/device'),
  //       name: 'add',
  //       meta: { title: '添加设备',
  //       roles: ['ROLE_ULTIMATE','ROLE_ADMIN'] ,// you can set roles in root nav
  //        noCache: true }
  //     },
  //     {
  //       path: 'devices',
  //       component: () => import('@/views/crane/device'),
  //       name: 'test',
  //       meta: { title: '设备信息',
  //       roles: ['ROLE_ULTIMATE','ROLE_ADMIN'] ,// you can set roles in root nav
  //       noCache: true }
  //     },
  //     {
  //       path: 'dataType',
  //       component: () => import('@/views/device/index'),
  //       name: 'dataType',
  //       meta: {
  //         title: '数据设置',
  //         roles: ['ROLE_ULTIMATE'] // you can set roles in root nav

  //         // if do not set roles, means: this page does not require permission
  //       }

  //     },

  //   ]
  // },

  {
    path: '/users',
    component: Layout,
    redirect: 'noRedirect',
    name: 'suply-chain',
    meta: {
      title: '用户管理',
      icon: 'user',
      roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'] // you can set roles in root nav
    },
    children: [
      {
        path: 'add',
        component: () => import('@/views/user/add'),
        name: 'add',
        meta: {
          title: '添加用户',
          roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'], // you can set roles in root nav
          noCache: true
        }
      },
      {
        path: 'info',
        component: () => import('@/views/user/info'),
        name: 'info',
        meta: {
          title: '用户信息',
          roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'], // you can set roles in root nav
          noCache: true
        }
      },
      {
        path: 'operate',
        component: () => import('@/views/user/test'),
        name: 'test',
        meta: {
          title: '操作记录',
          roles: ['ROLE_ULTIMATE', 'ROLE_ADMIN'], // you can set roles in root nav
          noCache: true
        }
      }

    ]
  },

  {
    path: '/setting',
    component: Layout,
    redirect: '/setting/role',
    // alwaysShow: true, // will always show the root menu
    name: 'setting',
    meta: {
      title: '系统设置',
      icon: 'lock',
      roles: ['ROLE_ULTIMATE'] // you can set roles in root nav
    },
    children: [
      {
        path: 'role',
        component: () => import('@/views/setting/role'),
        name: 'role',
        meta: {
          title: '角色设置',
          roles: ['ROLE_ULTIMATE'] // you can set roles in root nav

        }
      },

      {
        path: 'interface',
        component: () => import('@/views/setting/interface'),
        name: 'interface',
        meta: {
          title: '接口设置',
          roles: ['ROLE_ULTIMATE'] // you can set roles in root nav

          // if do not set roles, means: this page does not require permission
        }

      }

    ]
  },

  // {
  //   path: '/icon',
  //   component: Layout,
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/icons/index'),
  //       name: 'Icons',
  //       meta: { title: 'icons', icon: 'icon', noCache: true }
  //     }
  //   ]
  // },

  // /** when your routing map is too long, you can split it into small modules **/
  // componentsRouter,
  // chartsRouter,
  // nestedRouter,
  // tableRouter,

  // {
  //   path: '/example',
  //   component: Layout,
  //   redirect: '/example/list',
  //   name: 'Example',
  //   meta: {
  //     title: 'example',
  //     icon: 'el-icon-s-help'
  //   },
  //   children: [
  //     {
  //       path: 'create',
  //       component: () => import('@/views/example/create'),
  //       name: 'CreateArticle',
  //       meta: { title: 'createArticle', icon: 'edit' }
  //     },
  //     {
  //       path: 'edit/:id(\\d+)',
  //       component: () => import('@/views/example/edit'),
  //       name: 'EditArticle',
  //       meta: { title: 'editArticle', noCache: true, activeMenu: '/example/list' },
  //       hidden: true
  //     },
  //     {
  //       path: 'list',
  //       component: () => import('@/views/example/list'),
  //       name: 'ArticleList',
  //       meta: { title: 'articleList', icon: 'list' }
  //     }
  //   ]
  // },

  // {
  //   path: '/tab',
  //   component: Layout,
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/tab/index'),
  //       name: 'Tab',
  //       meta: { title: 'tab', icon: 'tab' }
  //     }
  //   ]
  // },

  // {
  //   path: '/error',
  //   component: Layout,
  //   redirect: 'noRedirect',
  //   name: 'ErrorPages',
  //   meta: {
  //     title: 'errorPages',
  //     icon: '404'
  //   },
  //   children: [
  //     {
  //       path: '401',
  //       component: () => import('@/views/error-page/401'),
  //       name: 'Page401',
  //       meta: { title: 'page401', noCache: true }
  //     },
  //     {
  //       path: '404',
  //       component: () => import('@/views/error-page/404'),
  //       name: 'Page404',
  //       meta: { title: 'page404', noCache: true }
  //     }
  //   ]
  // },

  // {
  //   path: '/error-log',
  //   component: Layout,
  //   children: [
  //     {
  //       path: 'log',
  //       component: () => import('@/views/error-log/index'),
  //       name: 'ErrorLog',
  //       meta: { title: 'errorLog', icon: 'bug' }
  //     }
  //   ]
  // },

  // {
  //   path: '/excel',
  //   component: Layout,
  //   redirect: '/excel/export-excel',
  //   name: 'Excel',
  //   meta: {
  //     title: 'excel',
  //     icon: 'excel'
  //   },
  //   children: [
  //     {
  //       path: 'export-excel',
  //       component: () => import('@/views/excel/export-excel'),
  //       name: 'ExportExcel',
  //       meta: { title: 'exportExcel' }
  //     },
  //     {
  //       path: 'export-selected-excel',
  //       component: () => import('@/views/excel/select-excel'),
  //       name: 'SelectExcel',
  //       meta: { title: 'selectExcel' }
  //     },
  //     {
  //       path: 'export-merge-header',
  //       component: () => import('@/views/excel/merge-header'),
  //       name: 'MergeHeader',
  //       meta: { title: 'mergeHeader' }
  //     },
  //     {
  //       path: 'upload-excel',
  //       component: () => import('@/views/excel/upload-excel'),
  //       name: 'UploadExcel',
  //       meta: { title: 'uploadExcel' }
  //     }
  //   ]
  // },

  // {
  //   path: '/zip',
  //   component: Layout,
  //   redirect: '/zip/download',
  //   alwaysShow: true,
  //   name: 'Zip',
  //   meta: { title: 'zip', icon: 'zip' },
  //   children: [
  //     {
  //       path: 'download',
  //       component: () => import('@/views/zip/index'),
  //       name: 'ExportZip',
  //       meta: { title: 'exportZip' }
  //     }
  //   ]
  // },

  // {
  //   path: '/pdf',
  //   component: Layout,
  //   redirect: '/pdf/index',
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/pdf/index'),
  //       name: 'PDF',
  //       meta: { title: 'pdf', icon: 'pdf' }
  //     }
  //   ]
  // },
  // {
  //   path: '/pdf/download',
  //   component: () => import('@/views/pdf/download'),
  //   hidden: true
  // },

  // {
  //   path: '/theme',
  //   component: Layout,
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/theme/index'),
  //       name: 'Theme',
  //       meta: { title: 'theme', icon: 'theme' }
  //     }
  //   ]
  // },

  // {
  //   path: '/clipboard',
  //   component: Layout,
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/clipboard/index'),
  //       name: 'ClipboardDemo',
  //       meta: { title: 'clipboardDemo', icon: 'clipboard' }
  //     }
  //   ]
  // },

  // {
  //   path: '/i18n',
  //   component: Layout,
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/i18n-demo/index'),
  //       name: 'I18n',
  //       meta: { title: 'i18n', icon: 'international' }
  //     }
  //   ]
  // },

  // {
  //   path: 'external-link',
  //   component: Layout,
  //   children: [
  //     {
  //       path: 'https://github.com/PanJiaChen/vue-element-admin',
  //       meta: { title: 'externalLink', icon: 'link' }
  //     }
  //   ]
  // },

  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
